@@ -11,6 +11,8 @@
 #' @param perm_boot_reps The number of times to repeat each set of permutations. Default is 5.
 #' @param models The models to select for stabilising. Default is elastic net (models = c("enet")), other available models include "lasso", "mbic", "mcp".
 #' @param type The type of model, either "linear" or "logistic"
+#' @param quantile The quantile of null stabilities to use as a threshold.
+#'
 #'
 #' @return A list for each model selected. Each list contains a dataframe of variable stabilities, a numeric permutation threshold, and a dataframe of coefficients for both bootstrap and permutation.
 #'
@@ -22,7 +24,7 @@
 #'
 utils::globalVariables(c("models"))
 
-stabilise <- function(data, outcome, boot_reps = "auto", permutations = "auto", perm_boot_reps = 20, models = c("enet"), type = "linear") {
+stabilise <- function(data, outcome, boot_reps = "auto", permutations = "auto", perm_boot_reps = 20, models = c("enet"), type = "linear", quantile = 1) {
   boot_reps <- rep_selector_boot(data = data, boot_reps = boot_reps)
   permutations <- rep_selector_perm(data = data, permutations = permutations)
 
@@ -41,7 +43,8 @@ stabilise <- function(data, outcome, boot_reps = "auto", permutations = "auto",
       permutations = permutations,
       perm_boot_reps = perm_boot_reps,
       model_name = .,
-      type = type
+      type = type,
+      quantile = quantile
     ))
 
   names(output) <- models
